@@ -249,13 +249,15 @@ class FormBase(ViewBase):
         return args
 
     def _do_get_fields(self):
-        """Override this function to define how
+        """Override this function to define what fields are available to the widget.
         """
         fields = super(FormBase, self)._do_get_fields()
         provider = self.__provider__
+        field_order = self.__field_order__ or []
         for relation in provider.get_relations(self.__entity__):
+            # do not remove field if it is listed in field_order
             for rel in provider.relation_fields(self.__entity__, relation):
-                if rel in fields:
+                if rel not in field_order and rel in fields:
                     fields.remove(rel)
         if 'sprox_id' not in fields:
             fields.append('sprox_id')
@@ -267,7 +269,7 @@ class FormBase(ViewBase):
         return widgets
 
     def _do_get_field_validator(self, field_name, field):
-        """Override thius function to define how a field validator is chosen for a given field.
+        """Override this function to define how a field validator is chosen for a given field.
         """
         v_type = self.__field_validator_types__.get(field_name, self.__validator_selector__[field])
         if field_name in self.__require_fields__ and v_type is None:
@@ -306,7 +308,8 @@ class EditableForm(FormBase):
         return fields
 
     def _do_get_fields(self):
-        """Override this function to define how
+        """Override this function to define what fields are available to the widget.
+
         """
         fields = super(EditableForm, self)._do_get_fields()
         if '_method' not in fields:
